#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.2
visibility:           public
id:                   hslua-module-system-1.1.2-JMQDaAC6euM6N0oBYXBcFO
key:                  hslua-module-system-1.1.2-JMQDaAC6euM6N0oBYXBcFO
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  4247ac59f804981663c8b60744086f94
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.2-JMQDaAC6euM6N0oBYXBcFO
depends:
    base-4.18.2.1 directory-1.3.8.5 exceptions-0.10.7
    hslua-core-2.3.2-LKfBNQBzih4B11MsDUkzCU
    hslua-marshalling-2.3.1-L0gS8fOJVsC3PgWUxw8tfr
    hslua-packaging-2.3.1-DLo447s2K6F6sfKMAWJXie
    temporary-1.3-1NBq1jdafNy1CacDIaV1ZS text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

